@@ -1,21 +1,25 @@
 # SPDX-FileCopyrightText: 2022 James R. Barlow
 # SPDX-License-Identifier: MPL-2.0
 
-"""
-Support functions called by the C++ library binding layer. Not intended to be
-called from Python, and subject to change at any time.
+"""Support functions called by the C++ library binding layer.
+
+Not intended to be called from Python, and subject to change at any time.
 """
 
 from __future__ import annotations
 
-from typing import Callable
+from typing import TYPE_CHECKING, Callable
 from warnings import warn
 
-from pikepdf import Dictionary, Name, Pdf
+from pikepdf.objects import Name
+
+if TYPE_CHECKING:
+    from pikepdf._core import Pdf
+    from pikepdf.objects import Dictionary
 
 
 def update_xmp_pdfversion(pdf: Pdf, version: str) -> None:
-
+    """Update XMP metadata to specified PDF version."""
     if Name.Metadata not in pdf.Root:
         return  # Don't create an empty XMP object just to store the version
 
@@ -38,7 +42,7 @@ def _alpha(n: int) -> str:
 
 
 def _roman(n: int) -> str:
-    """Converts integer n to Roman numeral representation as a string."""
+    """Convert integer n to Roman numeral representation as a string."""
     if not (1 <= n <= 5000):
         raise ValueError(f"Can't represent {n} in Roman numerals")
     roman_numerals = (
@@ -74,8 +78,7 @@ LABEL_STYLE_MAP: dict[Name, Callable[[int], str]] = {
 
 
 def label_from_label_dict(label_dict: int | Dictionary) -> str:
-    """Convert a label dictionary returned by QPDF into a text string."""
-
+    """Convert a label dictionary returned by qpdf into a text string."""
     if isinstance(label_dict, int):
         return str(label_dict)
 
